@@ -74,28 +74,13 @@ Preferences::Preferences()
 //---------------------------------------------------------------------------
 int Preferences::Config_Create()
 {
-    Config.Load(BaseFolder+__T("MediaInfo.cfg"));
+    if (File::Exists(BaseFolder+__T("MediaInfo.cfg")))
+        Config.Load(BaseFolder+__T("MediaInfo.cfg"));
+
     Config(__T("Version"))=MediaInfo_Version_GUI;
     Config(__T("NewestVersion"))=MediaInfo_Version_GUI;
-    if (Config(__T("Output")).empty()) Config(__T("Output"))=__T("Basic");
-    if (Config(__T("Language")).empty()) Config(__T("Language"))=__T("en");
-    if (Config(__T("Sheet")).empty()) Config(__T("Sheet"))=__T("Example");
-    if (Config(__T("Tree")).empty()) Config(__T("Tree"))=__T("Example");
-    if (Config(__T("Custom")).empty()) Config(__T("Custom"))=__T("Example");
-    if (Config(__T("CheckUpdate")).empty()) Config(__T("CheckUpdate"))=__T("1");
-    if (Config(__T("ShellExtension")).empty()) Config(__T("ShellExtension"))=__T("1");
-    if (Config(__T("ShellExtension_Folder")).empty()) Config(__T("ShellExtension_Folder"))=__T("0");
-    if (Config(__T("ShellInfoTip")).empty()) Config(__T("ShellInfoTip"))=__T("0");
-    if (Config(__T("ShowToolBar")).empty()) Config(__T("ShowToolBar"))=__T("1");
-    if (Config(__T("ShowMenu")).empty()) Config(__T("ShowMenu"))=__T("1");
-    if (Config(__T("CloseAllAuto")).empty()) Config(__T("CloseAllAuto"))=__T("1");
-    if (Config(__T("FirstInstall")).empty()) Config(__T("FirstInstall")).From_Number((int64u)time(NULL));
     Config(__T("Install")).From_Number((int64u)time(NULL));
-    if (Config(__T("Donated")).empty()) Config(__T("Donated"))=__T("0");
-    if (Config(__T("Donate_Display")).empty()) Config(__T("Donate_Display"))=__T("1");
-    Config.Save(BaseFolder+__T("MediaInfo.cfg"));
-
-    return 1;
+    return Config_Save();
 }
 
 //---------------------------------------------------------------------------
@@ -104,11 +89,21 @@ int Preferences::Config_Load()
     int Retour=1;
 
     //Base folder
-    BaseFolder=Application->ExeName.c_str();
-    BaseFolder=BaseFolder.substr(0, BaseFolder.rfind(__T("\\"))+1);
-    if (!Dir::Exists(BaseFolder+__T("Plugin")))
-        Dir::Create(BaseFolder+__T("Plugin"));
-    BaseFolder+=__T("Plugin\\");
+    TCHAR szPath[MAX_PATH];
+    if(FAILED(SHGetFolderPath(NULL, CSIDL_APPDATA, NULL, 0, szPath)))
+        return 1;
+    BaseFolder=szPath;
+    BaseFolder+=__T("\\MediaInfo");
+    if (!Dir::Exists(BaseFolder) || !Dir::Exists(BaseFolder+__T("\\Plugin")))
+    {
+        BaseFolder=Application->ExeName.c_str();
+        BaseFolder=BaseFolder.substr(0, BaseFolder.rfind(__T("\\"))+1);
+        if (!Dir::Exists(BaseFolder+__T("Plugin")))
+            Dir::Create(BaseFolder+__T("Plugin"));
+        BaseFolder+=__T("Plugin\\");
+    }
+    else
+        BaseFolder+=__T("\\Plugin\\");
 
     //Directories
     for (size_t Pos=0; Pos<FolderNames.size(); Pos++)
@@ -121,7 +116,8 @@ int Preferences::Config_Load()
     Load(Prefs_Language_English, __T("en"));
 
     //Configuration
-    Config.Load(BaseFolder+__T("MediaInfo.cfg"));
+    if (File::Exists(BaseFolder+__T("MediaInfo.cfg")))
+        Config.Load(BaseFolder+__T("MediaInfo.cfg"));
     if (Config.size()==0 || Config(__T("Version"))!=MediaInfo_Version_GUI)
     {
         Config_Create();
@@ -130,6 +126,18 @@ int Preferences::Config_Load()
 
     RefreshFilesList(Prefs_Language);
     Load(Prefs_Language, Config(FolderNames[Prefs_Language]));
+	{
+		//Now we prioritize language files in the app dir instead of the language files in the user dir
+		//TODO: forbid edit of default language files
+		ZenLib::Ztring BaseFolderOld=BaseFolder;
+		BaseFolder=Application->ExeName.c_str();
+		BaseFolder=BaseFolder.substr(0, BaseFolder.rfind(__T("\\"))+1);
+		if (!Dir::Exists(BaseFolder+__T("Plugin")))
+			Dir::Create(BaseFolder+__T("Plugin"));
+		BaseFolder+=__T("Plugin\\");
+		Load(Prefs_Language, Config(FolderNames[Prefs_Language]));
+		BaseFolder=BaseFolderOld;
+	}
     RefreshFilesList(Prefs_Sheet);
     Load(Prefs_Sheet, Config(FolderNames[Prefs_Sheet]));
     RefreshFilesList(Prefs_Tree);
@@ -182,7 +190,56 @@ int Preferences::Config_Load()
 //---------------------------------------------------------------------------
 int Preferences::Config_Save()
 {
-    return Config.Save();
+    if (Config(__T("Version")).empty()) Config(__T("Version"))=MediaInfo_Version_GUI;
+    if (Config(__T("NewestVersion")).empty()) Config(__T("NewestVersion"))=MediaInfo_Version_GUI;
+    if (Config(__T("Install")).empty()) Config(__T("Install")).From_Number((int64u)time(NULL));
+    if (Config(__T("Output")).empty()) Config(__T("Output"))=__T("Basic");
+    if (Config(__T("Language")).empty()) Config(__T("Language"))=__T("en");
+    if (Config(__T("Sheet")).empty()) Config(__T("Sheet"))=__T("Example");
+    if (Config(__T("Tree")).empty()) Config(__T("Tree"))=__T("Example");
+    if (Config(__T("Custom")).empty()) Config(__T("Custom"))=__T("Example");
+    if (Config(__T("CheckUpdate")).empty()) Config(__T("CheckUpdate"))=__T("1");
+    if (Config(__T("ShellExtension")).empty()) Config(__T("ShellExtension"))=__T("1");
+    if (Config(__T("ShellExtension_Folder")).empty()) Config(__T("ShellExtension_Folder"))=__T("0");
+    if (Config(__T("ShellInfoTip")).empty()) Config(__T("ShellInfoTip"))=__T("0");
+    if (Config(__T("ShowToolBar")).empty()) Config(__T("ShowToolBar"))=__T("1");
+    if (Config(__T("ShowMenu")).empty()) Config(__T("ShowMenu"))=__T("1");
+    if (Config(__T("CloseAllAuto")).empty()) Config(__T("CloseAllAuto"))=__T("1");
+    if (Config(__T("FirstInstall")).empty()) Config(__T("FirstInstall")).From_Number((int64u)time(NULL));
+    if (Config(__T("Donated")).empty()) Config(__T("Donated"))=__T("0");
+    if (Config(__T("Donate_Display")).empty()) Config(__T("Donate_Display"))=__T("1");
+
+    HANDLE Temp=CreateFile((BaseFolder+__T("MediaInfo.cfg")).c_str(), GENERIC_WRITE, 0, NULL, CREATE_ALWAYS, 0, NULL);
+    if (Temp==INVALID_HANDLE_VALUE)
+    {
+        //Base folder
+        TCHAR szPath[MAX_PATH];
+        if(FAILED(SHGetFolderPath(NULL, CSIDL_APPDATA, NULL, 0, szPath)))
+            return 1;
+        Ztring NewBaseFolder=szPath;
+        NewBaseFolder+=__T("\\MediaInfo");
+        if (!Dir::Exists(NewBaseFolder) || !Dir::Exists(NewBaseFolder+__T("\\Plugin")))
+        {
+            Dir::Create(BaseFolder);
+
+            Ztring From=BaseFolder+__T('\0');
+            Ztring To=NewBaseFolder+__T("\\Plugin\0");
+
+            SHFILEOPSTRUCT s = { 0 };
+            s.hwnd = NULL;
+            s.wFunc = FO_COPY;
+            s.fFlags = FOF_SILENT;
+            s.pFrom = From.c_str();
+            s.pTo = To.c_str();
+            SHFileOperation(&s);
+        }
+
+        BaseFolder=NewBaseFolder+__T("\\Plugin\\");
+    }
+    else
+        CloseHandle(Temp);
+
+    return Config.Save(BaseFolder+__T("MediaInfo.cfg"));;
 }
 
 //---------------------------------------------------------------------------
@@ -337,7 +394,7 @@ void __fastcall ThreadInternetCheck::Execute()
         return; //No internet connexion
 
     HTTP_Client H;
-    if (H.Open(Ztring(__T("http://MediaArea.net/MediaInfo_check/changelog_"))+MediaInfo_Version_GUI+__T(".bin"))==0)
+    if (H.Open(Ztring(__T("http://MediaArea.net/mediainfo_check/changelog_"))+MediaInfo_Version_GUI+__T(".bin"))==0)
         return;
 
     Ztring Z=H.Read();
@@ -366,19 +423,19 @@ void __fastcall ThreadInternetCheck::Execute()
         //Inscription version connue pour pas repeter l'avertissement
         int Version_Pos=Prefs->Config.Find(__T("NewestVersion"));
         Prefs->Config(Version_Pos, 1)=NewestVersion;
-        Prefs->Config.Save();
+        Prefs->Config_Save();
     }
 
     //Donation button
     if (Prefs->Config(__T("Donate_Display"))==__T("0") && Download(__T("DonateButton"))==__T("1"))
     {
         Prefs->Config(__T("Donate_Display"))=__T("1");
-        Prefs->Config.Save();
+        Prefs->Config_Save();
     }
     if (Prefs->Config(__T("Donate_Display"))==__T("1") && Download(__T("DonateButton"))==__T("0"))
     {
         Prefs->Config(__T("Donate_Display"))=__T("0");
-        Prefs->Config.Save();
+        Prefs->Config_Save();
     }
 
     //Chargement de pages
@@ -468,6 +525,7 @@ int Preferences::ExplorerShell()
         ".mka;MKAFile\r\n"
         ".mks;MKSFile\r\n"
         ".mkv;MKVFile\r\n"
+        ".mlp;MLPFile\r\n"
         ".mod;modFile\r\n"
         ".mov;MOVFile\r\n"
         ".mp+;mpcFile\r\n"
@@ -475,6 +533,7 @@ int Preferences::ExplorerShell()
         ".mp3;mp3File\r\n"
         ".mp4;mpeg4File\r\n"
         ".mpc;mpcFile\r\n"
+        ".mpd;mpdFile\r\n"
         ".mpe;mpegFile\r\n"
         ".mpeg;mpegFile\r\n"
         ".mpg;mpegFile\r\n"
@@ -499,7 +558,8 @@ int Preferences::ExplorerShell()
         ".smv;SMVFile\r\n"
         ".stl;STLFile\r\n"
         ".swf;FlashFile\r\n"
-        ".tp;FlashVideoFile\r\n"
+        ".tak;TakVideoFile\r\n"
+        ".tp;TPFile\r\n"
         ".trp;TRPFile\r\n"
         ".ts;tsFile\r\n"
         ".tta;TTAFile\r\n"
@@ -528,31 +588,31 @@ int Preferences::ExplorerShell()
         if (Result==0)
         {
             RegCloseKey(Key);
-            Result=RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\*\\Shell\\Media Info\\Command"));
+            RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\*\\Shell\\Media Info\\Command"));
         }
         Result=RegOpenKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\*\\Shell\\Media Info"), 0, KEY_READ, &Key);
         if (Result==0)
         {
             RegCloseKey(Key);
-            Result=RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\*\\Shell\\Media Info"));
+            RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\*\\Shell\\Media Info"));
         }
         Result=RegOpenKeyEx(HKEY_CLASSES_ROOT, __T("*\\Shell\\MediaInfo\\Command"), 0, KEY_READ, &Key);
         if (Result==0)
         {
             RegCloseKey(Key);
-            Result=RegDeleteKey(HKEY_CLASSES_ROOT, __T("*\\Shell\\MediaInfo\\Command"));
+            RegDeleteKey(HKEY_CLASSES_ROOT, __T("*\\Shell\\MediaInfo\\Command"));
         }
         Result=RegOpenKeyEx(HKEY_CLASSES_ROOT, __T("*\\Shell\\MediaInfo"), 0, KEY_READ, &Key);
         if (Result==0)
         {
             RegCloseKey(Key);
-            Result=RegDeleteKey(HKEY_CLASSES_ROOT, __T("*\\Shell\\MediaInfo"));
+            RegDeleteKey(HKEY_CLASSES_ROOT, __T("*\\Shell\\MediaInfo"));
         }
         Result=RegOpenKeyEx(HKEY_CURRENT_USER, __T("Software\\MediaInfo"), 0, KEY_READ, &Key);
         if (Result==0)
         {
             RegCloseKey(Key);
-            Result=RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\MediaInfo"));
+            RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\MediaInfo"));
         }
     }
 
@@ -1050,6 +1110,7 @@ int Preferences::ShellToolTip()
         ".m4b;mpeg4File\r\n"
         ".m4v;mpeg4File\r\n"
         ".mac;APEFile\r\n"
+        ".mlp;MLPFile\r\n"
         ".mka;MKAFile\r\n"
         ".mks;MKSFile\r\n"
         ".mkv;MKVFile\r\n"
@@ -1060,6 +1121,7 @@ int Preferences::ShellToolTip()
         ".mp3;mp3File\r\n"
         ".mp4;mpeg4File\r\n"
         ".mpc;mpcFile\r\n"
+        ".mpd;mpdFile\r\n"
         ".mpe;mpegFile\r\n"
         ".mpeg;mpegFile\r\n"
         ".mpg;mpegFile\r\n"
@@ -1084,7 +1146,8 @@ int Preferences::ShellToolTip()
         ".smv;SMVFile\r\n"
         ".stl;STLFile\r\n"
         ".swf;FlashFile\r\n"
-        ".tp;FlashVideoFile\r\n"
+        ".tak;TAKFile\r\n"
+        ".tp;TPFile\r\n"
         ".trp;TRPFile\r\n"
         ".ts;tsFile\r\n"
         ".tta;TTAFile\r\n"
@@ -1117,7 +1180,7 @@ int Preferences::ShellToolTip()
             Ztring ShellInfoTipToWrite=__T("\"") + DLL_Name + __T("\"");
             DWORD ShellInfoTip_Size=65536;
             ZenLib::Char ShellInfoTip_Chars[65536];
-            Result=RegQueryValueEx(Key, NULL, 0, NULL, (LPBYTE)&ShellInfoTip_Chars, &ShellInfoTip_Size);
+            RegQueryValueEx(Key, NULL, 0, NULL, (LPBYTE)&ShellInfoTip_Chars, &ShellInfoTip_Size);
             if (Result!=ERROR_SUCCESS)
             {
                 RegCloseKey(Key);
@@ -1152,48 +1215,48 @@ int Preferences::ShellToolTip()
             if (RegDeleteKeyEx_ShouldUse)
             {
                 //Should not be here, deleting
-                Result=_RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\VersionIndependentProgID"), KEY_WOW64_64KEY, 0);
-                Result=_RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\TypeLib"), KEY_WOW64_64KEY, 0);
-                Result=_RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\ProcID"), KEY_WOW64_64KEY, 0);
-                Result=_RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\InprocServer32"), KEY_WOW64_64KEY, 0);
-                Result=_RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}"), KEY_WOW64_64KEY, 0);
-                Result=_RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}"), KEY_WOW64_64KEY, 0);
-                Result=_RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_\\CurVer"), KEY_WOW64_64KEY, 0);
-                Result=_RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_\\CLSID"), KEY_WOW64_64KEY, 0);
-                Result=_RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_"), KEY_WOW64_64KEY, 0);
-                Result=_RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_.1\\CLSID"), KEY_WOW64_64KEY, 0);
-                Result=_RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_.1"), KEY_WOW64_64KEY, 0);
+                _RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\VersionIndependentProgID"), KEY_WOW64_64KEY, 0);
+                _RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\TypeLib"), KEY_WOW64_64KEY, 0);
+                _RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\ProcID"), KEY_WOW64_64KEY, 0);
+                _RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\InprocServer32"), KEY_WOW64_64KEY, 0);
+                _RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}"), KEY_WOW64_64KEY, 0);
+                _RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}"), KEY_WOW64_64KEY, 0);
+                _RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_\\CurVer"), KEY_WOW64_64KEY, 0);
+                _RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_\\CLSID"), KEY_WOW64_64KEY, 0);
+                _RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_"), KEY_WOW64_64KEY, 0);
+                _RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_.1\\CLSID"), KEY_WOW64_64KEY, 0);
+                _RegDeleteKeyEx(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_.1"), KEY_WOW64_64KEY, 0);
                 for (size_t I1=0; I1<List.size(); I1++)
                 {
                     //Remove
                     if (!List(I1, 0).empty())
                     {
-                        Result=_RegDeleteKeyEx(HKEY_CURRENT_USER, (__T("Software\\Classes\\")+List(I1, 0)+__T("\\shellex\\{00021500-0000-0000-C000-000000000046}")).c_str(), KEY_WOW64_64KEY, 0);
-                        //Result=_RegDeleteKeyEx(HKEY_CURRENT_USER, (__T("Software\\Classes\\")+List(I1, 0)+__T("\\shellex")).c_str(), KEY_WOW64_64KEY, 0);
+                        _RegDeleteKeyEx(HKEY_CURRENT_USER, (__T("Software\\Classes\\")+List(I1, 0)+__T("\\shellex\\{00021500-0000-0000-C000-000000000046}")).c_str(), KEY_WOW64_64KEY, 0);
+                        //_RegDeleteKeyEx(HKEY_CURRENT_USER, (__T("Software\\Classes\\")+List(I1, 0)+__T("\\shellex")).c_str(), KEY_WOW64_64KEY, 0);
                     }
                 }
             }
             else
             {
                 //Should not be here, deleting
-                Result=RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\VersionIndependentProgID"));
-                Result=RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\TypeLib"));
-                Result=RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\ProcID"));
-                Result=RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\InprocServer32"));
-                Result=RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}"));
-                Result=RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}"));
-                Result=RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_\\CurVer"));
-                Result=RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_\\CLSID"));
-                Result=RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_"));
-                Result=RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_.1\\CLSID"));
-                Result=RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_.1"));
+                RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\VersionIndependentProgID"));
+                RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\TypeLib"));
+                RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\ProcID"));
+                RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\InprocServer32"));
+                RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}"));
+                RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}"));
+                RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_\\CurVer"));
+                RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_\\CLSID"));
+                RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_"));
+                RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_.1\\CLSID"));
+                RegDeleteKey(HKEY_CURRENT_USER, __T("Software\\Classes\\MediaInfoShellExt.MediaInfoShellExt_.1"));
                 for (size_t I1=0; I1<List.size(); I1++)
                 {
                     //Remove
                     if (!List(I1, 0).empty())
                     {
-                        Result=RegDeleteKey(HKEY_CURRENT_USER, (__T("Software\\Classes\\")+List(I1, 0)+__T("\\shellex\\{00021500-0000-0000-C000-000000000046}")).c_str());
-                        //Result=RegDeleteKey(HKEY_CURRENT_USER, (__T("Software\\Classes\\")+List(I1, 0)+__T("\\shellex")).c_str());
+                        RegDeleteKey(HKEY_CURRENT_USER, (__T("Software\\Classes\\")+List(I1, 0)+__T("\\shellex\\{00021500-0000-0000-C000-000000000046}")).c_str());
+                        //RegDeleteKey(HKEY_CURRENT_USER, (__T("Software\\Classes\\")+List(I1, 0)+__T("\\shellex")).c_str());
                     }
                 }
             }
