@@ -125,7 +125,7 @@ namespace MediaInfoLib
 {
 
 //---------------------------------------------------------------------------
-const Char*  MediaInfo_Version=__T("MediaInfoLib - v0.7.83");
+const Char*  MediaInfo_Version=__T("MediaInfoLib - v0.7.87");
 const Char*  MediaInfo_Url=__T("http://MediaArea.net/MediaInfo");
       Ztring EmptyZtring;       //Use it when we can't return a reference to a true Ztring
 const Ztring EmptyZtring_Const; //Use it when we can't return a reference to a true Ztring, const version
@@ -217,6 +217,7 @@ void MediaInfo_Config::Init()
     Verbosity=(float32)0.5;
     Trace_Level=(float32)0.0;
     Compat=70778;
+    Https=true;
     Trace_TimeSection_OnlyFirstOccurrence=false;
     Trace_Format=Trace_Format_Tree;
     Language_Raw=false;
@@ -597,12 +598,31 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
             Inform_Set(Ztring());
             Trace_Format_Set(Trace_Format_XML); // TODO: better coherency in options
         }
+        if (Inform_Get()==__T("MICRO_XML"))
+        {
+            Inform_Set(Ztring());
+            Trace_Format_Set(Trace_Format_MICRO_XML);
+        }
         return Ztring();
     }
     else if (Option_Lower==__T("trace_level_get"))
     {
         return Ztring::ToZtring(Trace_Level_Get());
     }
+    else if (Option_Lower==__T("https"))
+    {
+        Https_Set(Value.To_int64u()?true:false);
+        return Ztring();
+    }
+    else if (Option_Lower==__T("no-https"))
+    {
+        Https_Set(false);
+        return Ztring();
+    }
+    else if (Option_Lower==__T("https_get"))
+    {
+        return Https_Get()?__T("1"):__T("0");
+    }
     else if (Option_Lower==__T("trace_timesection_onlyfirstoccurrence"))
     {
         Trace_TimeSection_OnlyFirstOccurrence_Set(Value.To_int64u()?true:false);
@@ -630,6 +650,8 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
             Trace_Format_Set(Trace_Format_CSV);
         else if (NewValue_Lower==__T("xml") || NewValue_Lower==__T("MAXML"))
             Trace_Format_Set(Trace_Format_XML);
+        else if (NewValue_Lower==__T("micro_xml"))
+            Trace_Format_Set(Trace_Format_MICRO_XML);
         else
             Trace_Format_Set(Trace_Format_Tree);
         return Ztring();
@@ -1228,6 +1250,20 @@ int64u MediaInfo_Config::Compat_Get ()
     return Compat;
 }
 
+//---------------------------------------------------------------------------
+void MediaInfo_Config::Https_Set(bool NewValue)
+{
+    CriticalSectionLocker CSL(CS);
+    Https=NewValue;
+}
+
+bool MediaInfo_Config::Https_Get()
+{
+    CriticalSectionLocker CSL(CS);
+    return Https;
+}
+
+//---------------------------------------------------------------------------
 std::bitset<32> MediaInfo_Config::Trace_Layers_Get ()
 {
     CriticalSectionLocker CSL(CS);
@@ -1621,6 +1657,11 @@ void MediaInfo_Config::Inform_Set (const ZtringListList &NewValue)
         Trace_Format_Set(Trace_Format_XML); // TODO: better coherency in options
         return;
     }
+    else if (Trace_Level_Get() && NewValue.Read(0, 0)==__T("MICRO_XML"))
+    {
+        Trace_Format_Set(Trace_Format_MICRO_XML);
+        return;
+    }
     else
     {
         if (NewValue.Read(0, 0)==__T("MAXML"))
